@@ -210,6 +210,8 @@ def reset_user_password():
     Endpoint for resetting a ldap user password.
     required parameters:
         'employeeNumber' - a registration_number
+    not required parameter:
+        'password'
     """
     parameters = request.get_json()
     ldap_handler = LdapHandler()
@@ -220,14 +222,14 @@ def reset_user_password():
     )
     if user_exists:
         user_tree, user_info = ldap_handler.parse_search(user_exists[0])
-        password = ldap_handler.generate_password()
+        password = parameters.get("password", ldap_handler.generate_password())
         ldap_handler.update("User", user_tree, {"userPassword": password}, overwrite=True)
-        EmailHandler().reset(
-            name=user_info['sn'],
-            username=user_info['uid'],
-            password=password,
-            email=user_info['mail']
-        )
+        # EmailHandler().reset(
+        #     name=user_info['sn'],
+        #     username=user_info['uid'],
+        #     password=password,
+        #     email=user_info['mail']
+        # )
         return "Password reset."
     else:
         return "User not found."
