@@ -14,7 +14,6 @@ from itsdangerous import JSONWebSignatureSerializer as JWS
 from itsdangerous import BadSignature, SignatureExpired
 
 from . import consts, core
-from .consts.LOGS import logger
 
 
 __all__ = ["LdapHandler", ]
@@ -226,7 +225,7 @@ class LdapHandler:
                     .format(object_tree, destination_tree)
                 )
             except ldap.NO_SUCH_OBJECT:
-                logger.warning("User {} is not in job tree. Operation skipped.".format(object_tree))
+                consts.LOGS.logger.warning("User {} is not in job tree. Operation skipped.".format(object_tree))
         else:
             raise NotImplementedError
 
